@@ -27,20 +27,23 @@
 import ConfigParser
 import UserDict
 import subprocess
+import collections
+import re
+import distro_info
 
 
 class MissingSection(Exception):
 
     def __init__(self, filename, section):
         self.args = "Section %s not defined in configuration file %s" % \
-            (section, filename)
+            (section, filename),
 
 
 class MissingMandatorySetting(Exception):
 
     def __init__(self, filename, key):
         self.args = "Value for %s not set in configuration file %s" % \
-            (key, filename)
+            (key, filename),
 
 
 class Config(UserDict.UserDict):
@@ -96,6 +99,41 @@ class Config(UserDict.UserDict):
             return distros[-1]
         return self["distro"]
 
+    def _get_distmap(self):
+        debdist = distro_info.DebianDistroInfo()
+
+        # start with e.g. "sid" -> "unstable"
+        distmap = collections.defaultdict( lambda : "unknown", [
+                              (debdist.old(), "oldstable"),
+                              (debdist.devel(), "unstable"),
+                              (debdist.stable(), "stable"),
+                              (debdist.testing(), "testing"),
+                              ("experimental", "experimental"),
+                              ("rc", "experimental"),
+                              ])
+
+        # add mappings for e.g. "oldstable" -> "oldstable"
+        distmap.update(dict([(val, val) for key, val in distmap.iteritems()]))
+
+        # map e.g. "Debian6" -> "oldstable" where debdist.old(result="fullname")
+        # currently returns 'Debian 6.0 "Squeeze"'
+        dkey = lambda x: "Debian" + re.split('[ \.]', x(result="fullname"))[1]
+        dfuncs = [debdist.old, debdist.stable, debdist.testing]
+        distmap.update(dict([(dkey(x),distmap[x()]) for x in dfuncs]))
+
+        return distmap
+
+    def _map_distro(self, distro):
+        distro_root = re.split("[\-\.]", distro)[0]
+        distmap = self._get_distmap()
+        return distmap[distro_root]
+
+    def get_std_distro(self, distrolist=[]):
+        if not distrolist:
+            distrolist = [self.get_distro()] + self.get_distros()
+        mappedlist = [self._map_distro(x) for x in distrolist]
+        return reduce(lambda x,y: y if y != "unknown" else x, mappedlist)
+
     def get_area(self):
         if self["area"] is not None:
             return self["area"]
@@ -156,7 +194,7 @@ class DistroConfig(UserDict.UserDict):
         return (self.get(distro, "candidates") or "").split() or [distro]
 
     def _get_packages_url(self, distro, area, arch):
-        return "%s/dists/%s/%s/binary-%s/Packages.bz2" % (
+        return "%s/dists/%s/%s/binary-%s/Packages" % (
                 self.get_mirror(distro),
                 self.get_distribution(distro),
                 area, arch)
@@ -166,7 +204,7 @@ class DistroConfig(UserDict.UserDict):
                 for d in self.get_candidates(distro)]
 
     def _get_sources_url(self, distro, area):
-        return "%s/dists/%s/%s/source/Sources.bz2" % (
+        return "%s/dists/%s/%s/source/Sources" % (
                 self.get_mirror(distro),
                 self.get_distribution(distro),
                 area)
